Check if an action has proceeded
check_functions.RdThese functions check other functions to capture their output to determine if they are functioning properly
Usage
check_dropdowns(
common_name_choices,
grouping_choices,
numeric_choices,
waterbody_choices
)
check_input_source(input_source_name, envir = parent.frame())
check_hist_ui(df, var, type_val, col)
check_hist_vars(df, var, ba)
check_mean_data(df, summary_grouping_vars, y_vals)
check_selected_vars(selected_vars)
check_summary_data(df, name = deparse(substitute(df)))
check_tab_name(tab)Arguments
- common_name_choices
selected `common_name` choices
- grouping_choices
selected categorical grouping choices
- numeric_choices
selected numerical column choices
- waterbody_choices
selected `waterbody` choices
- input_source_name
a `character` string for the input source
- envir
collect the current environment present whether that is the global environment or another environment.
- df
a `tbl_sql` object that resembles a dataframe
- var
selected variable for plotting
- type_val
the selected type val for variable used in plotting
- col
a column from the dataframe
- ba
before or after to be used before something is selected and after something is selected
- summary_grouping_vars
selected grouping variables for summary
- y_vals
selected y_vals
- selected_vars
is a selected variable of interest for plotting and/or summarizing the dataframe
- name
the name of the dataframe
- tab
selected tab for reactive summary