Skip to contents

These functions create reactive statements that can be used by `shiny` to create data objects using `get_functions()`

Usage

create_filtered_data(input_source, data)

create_mean_data(input_source, data)

create_sidebar_df(con)

create_summary_data(con, main_input, input_source, var_field, tab = NULL)

Arguments

input_source

determine where to get variables to create queries and filters.

data

usually a `tbl_sql` object that resembles a dataframe.

con

a DBI connection to a database in this case PostgresSQLx

main_input

which main input is being used similar to tab

var_field

which fields to use to get selected variables for summarizing or plotting. (e.g., `y_choices`)

tab

which tab is activated