Connect to a database and do different actions such as getting tables and queries.
get_functions.RdThese functions connect to a database and do different actions such as getting tables and queries.
Usage
get_column_map(con)
get_data(con, debug_sql = FALSE)
get_good_groups(df)
get_join_table(con, df, table)
get_var_types(df, var)
get_numeric_vars(con)
get_selected_tab(input)
get_summary_data(
con,
selected_vars = NULL,
grouping_vars = NULL,
debug_sql = FALSE
)
get_tables_needed(con, var)
get_var_types(df, var)Arguments
- con
a DBI connection to a database in this case PostgresSQL
- debug_sql
prints SQL to allow debugging. Default is `FALSE`.
- df
a `tbl_sql` to get good groups
- table
a `character` string for the table desired
- var
a `character` string that indicates the variable of interest (e.g., lenght_type, fork ect.)
- input
shiny input
- selected_vars
a vector of `character` strings for variables that are wanted to summarise.
- grouping_vars
a `character` string of grouping variables of interest.